Vendored patternfly assets
==========================

- https://unpkg.com/@patternfly/patternfly@2.56.3/patternfly.min.css
- https://unpkg.com/@patternfly/patternfly@2.56.3/assets/fonts/overpass-webfont/overpass-semibold.woff2
- https://unpkg.com/@patternfly/patternfly@2.56.3/assets/fonts/overpass-webfont/overpass-light.woff2
- https://unpkg.com/@patternfly/patternfly@2.56.3/assets/fonts/overpass-webfont/overpass-regular.woff2
- https://unpkg.com/@patternfly/patternfly@2.56.3/assets/fonts/overpass-webfont/overpass-bold.woff2
- https://unpkg.com/@patternfly/patternfly@2.56.3/assets/fonts/webfonts/fa-solid-900.woff2
